#**************************************************************************
# * Copyright (C) 2023-present Bert Van Acker (B.MKR) <bva.bmkr@gmail.com>
# *
# * This file is part of the hybridIO project.
# *
# * HybridIO can not be copied and/or distributed without the express
# * permission of Bert Van Acker
# *************************************************************************

VERSION = (0, 3, "14")
__version__ = ".".join([str(s) for s in VERSION])

__title__ = "robosapiensio"
__description__ = (
    "robosapiensIO - your gateway to trustworthy self-adaptive robotics."
)
__url__ = "https://rpio.readthedocs.io/en/latest/index.html"

__author__ = "Sahar Nasimi Nezhad & Bert Van Acker"
__email__ = "bert.vanacker@uantwerpen.be"

__license__ = "Apache License 2.0"
__copyright__ = "Copyright 2024"
